@@ -3,12 +3,12 @@ use warnings;
 
 package AtomicParsley::Command::Tags;
 {
-  $AtomicParsley::Command::Tags::VERSION = '1.120560';
+  $AtomicParsley::Command::Tags::VERSION = '1.120620';
 }
 
 # ABSTRACT: represent the mp4 metatags
 
-use String::Util 'hascontent';
+use Params::Util qw{_STRING};
 
 use Object::Tiny qw{
   artist
@@ -51,11 +51,7 @@ sub prepare {
     # loop through all accessors and generate parameters for AP
     my @out;
     while ( my ( $key, $value ) = each(%$self) ) {
-        next
-          unless defined $value
-              && ref($value) ne 'HASH'
-              && ref($value) ne 'ARRAY'
-              && hascontent($value);
+        next unless _STRING($value);
 
         push @out, "--$key";
         push @out, $value;
@@ -76,7 +72,7 @@ AtomicParsley::Command::Tags - represent the mp4 metatags
 
 =head1 VERSION
 
-version 1.120560
+version 1.120620
 
 =head1 SYNOPSIS
 
